@@ -41,6 +41,7 @@
 #include <KBookmarkDomBuilder>
 #include <QStandardPaths>
 #include <kbookmarkimporter_ns.h>
+#include <kwidgetsaddons_version.h>
 
 ImportCommand::ImportCommand(KBookmarkModel *model)
     : QUndoCommand()
@@ -95,18 +96,26 @@ ImportCommand *ImportCommand::performImport(KBookmarkModel *model, const QString
         return nullptr;
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    int answer = KMessageBox::questionTwoActionsCancel(top,
+#else
     int answer = KMessageBox::questionYesNoCancel(top,
-                                                  i18n("Import as a new subfolder or replace all the current bookmarks?"),
-                                                  i18nc("@title:window", "%1 Import", importer->visibleName()),
-                                                  KGuiItem(i18n("As New Folder")),
-                                                  KGuiItem(i18n("Replace")));
+#endif
+                                                       i18n("Import as a new subfolder or replace all the current bookmarks?"),
+                                                       i18nc("@title:window", "%1 Import", importer->visibleName()),
+                                                       KGuiItem(i18n("As New Folder")),
+                                                       KGuiItem(i18n("Replace")));
 
     if (answer == KMessageBox::Cancel) {
         delete importer;
         return nullptr;
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    importer->import(mydirname, answer == KMessageBox::ButtonCode::PrimaryAction);
+#else
     importer->import(mydirname, answer == KMessageBox::Yes);
+#endif
     return importer;
 }
 
